#!/usr/bin/python
# -*- coding: UTF-8 -*-

############################################################################
##                                                                        ##
## Bookkun - Manage your ebooks.                                          ##
##                                                                        ##
## Copyright (C) 2012  Fabien Loison <flo AT flogisoft DOT com>           ##
##                                                                        ##
## This program is free software: you can redistribute it and/or modify   ##
## it under the terms of the GNU General Public License as published by   ##
## the Free Software Foundation, either version 3 of the License, or      ##
## (at your option) any later version.                                    ##
##                                                                        ##
## This program is distributed in the hope that it will be useful,        ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
## GNU General Public License for more details.                           ##
##                                                                        ##
## You should have received a copy of the GNU General Public License      ##
## along with this program.  If not, see <http://www.gnu.org/licenses/>.  ##
##                                                                        ##
############################################################################


import re
import os
import unicodedata

from bookkun.exceptions import ResourceNotFound, UnknownResourceType


def searchable_string(string):
    """Make a searchable string.

    This function remove all accents, converts to lower case and remove
    any character that is not a letter or a number.

    Return:
        The searchable string.
    """
    if isinstance(string, str):
        string = unicode(string, "utf8", "replace")
    string = unicodedata.normalize("NFD", string)
    string = string.lower()
    string = re.sub("[\W]", "", string)
    return string.encode("ascii", "ignore")


def get_resource(name):
    """Get the path of a resource.

    The resource can be a .glade, (TODO: .html, .png).

    Args:
        name -- The resource name (e.g. main.glade).

    Return:
        The path of the resource.
    """

    handled_res = {
            'glade': _get_resource_glade,
            }

    ext = name.split(".")[-1].lower()

    if ext in handled_res:
        return handled_res[ext](name)

    raise UnknownResourceType(name)


def _get_resource_glade(name):
    path = os.path.join(os.path.dirname(__file__), "ui", "glade", name)
    if os.path.isfile(path):
        return path
    raise ResourceNotFound(name)
